Class: Google::Apis::TagmanagerV2::Account
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Account
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Account.
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account ID uniquely identifies the GTM Account.
-
#features ⇒ Google::Apis::TagmanagerV2::AccountFeatures
Read-only Account feature set Corresponds to the JSON property
features. -
#fingerprint ⇒ String
The fingerprint of the GTM Account as computed at storage time.
-
#name ⇒ String
Account display name.
-
#path ⇒ String
GTM Account's API relative path.
-
#share_data ⇒ Boolean
(also: #share_data?)
Whether the account shares data anonymously with Google and others.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Account
constructor
A new instance of Account.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Account
Returns a new instance of Account.
70 71 72 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 70 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
The Account ID uniquely identifies the GTM Account.
Corresponds to the JSON property accountId
32 33 34 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 32 def account_id @account_id end |
#features ⇒ Google::Apis::TagmanagerV2::AccountFeatures
Read-only Account feature set
Corresponds to the JSON property features
37 38 39 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 37 def features @features end |
#fingerprint ⇒ String
The fingerprint of the GTM Account as computed at storage time. This value is
recomputed whenever the account is modified.
Corresponds to the JSON property fingerprint
43 44 45 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 43 def fingerprint @fingerprint end |
#name ⇒ String
Account display name.
Corresponds to the JSON property name
48 49 50 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 48 def name @name end |
#path ⇒ String
GTM Account's API relative path.
Corresponds to the JSON property path
53 54 55 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 53 def path @path end |
#share_data ⇒ Boolean Also known as:
Whether the account shares data anonymously with Google and others. This flag
enables benchmarking by sharing your data in an anonymous form. Google will
remove all identifiable information about your website, combine the data with
hundreds of other anonymous sites and report aggregate trends in the
benchmarking service.
Corresponds to the JSON property shareData
62 63 64 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 62 def share_data @share_data end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
68 69 70 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 68 def tag_manager_url @tag_manager_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 75 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @features = args[:features] if args.key?(:features) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @share_data = args[:share_data] if args.key?(:share_data) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) end |