Class: Google::Apis::TagmanagerV2::BuiltInVariable
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::BuiltInVariable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Built-in variables are a special category of variables that are pre-created and non-customizable. They provide common functionality like accessing properties of the gtm data layer, monitoring clicks, or accessing elements of a page URL.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#container_id ⇒ String
GTM Container ID.
-
#name ⇒ String
Name of the built-in variable to be used to refer to the built-in variable.
-
#path ⇒ String
GTM BuiltInVariable's API relative path.
-
#type ⇒ String
Type of built-in variable.
-
#workspace_id ⇒ String
GTM Workspace ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuiltInVariable
constructor
A new instance of BuiltInVariable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuiltInVariable
Returns a new instance of BuiltInVariable.
169 170 171 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
142 143 144 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 142 def account_id @account_id end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
147 148 149 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 147 def container_id @container_id end |
#name ⇒ String
Name of the built-in variable to be used to refer to the built-in variable.
Corresponds to the JSON property name
152 153 154 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 152 def name @name end |
#path ⇒ String
GTM BuiltInVariable's API relative path.
Corresponds to the JSON property path
157 158 159 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 157 def path @path end |
#type ⇒ String
Type of built-in variable.
Corresponds to the JSON property type
162 163 164 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 162 def type @type end |
#workspace_id ⇒ String
GTM Workspace ID.
Corresponds to the JSON property workspaceId
167 168 169 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 167 def workspace_id @workspace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
174 175 176 177 178 179 180 181 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 174 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container_id = args[:container_id] if args.key?(:container_id) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @type = args[:type] if args.key?(:type) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) end |