Class: Google::Apis::TagmanagerV2::Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Container, which specifies the platform tags will run on, manages workspaces, and retains container versions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Container

Returns a new instance of Container.



426
427
428
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


361
362
363
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 361

def 
  @account_id
end

#container_idString

The Container ID uniquely identifies the GTM Container. Corresponds to the JSON property containerId

Returns:

  • (String)


366
367
368
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 366

def container_id
  @container_id
end

#domain_nameArray<String>

List of domain names associated with the Container. Corresponds to the JSON property domainName

Returns:

  • (Array<String>)


371
372
373
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 371

def domain_name
  @domain_name
end

#featuresGoogle::Apis::TagmanagerV2::ContainerFeatures

Read-only Container feature set. Corresponds to the JSON property features



376
377
378
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 376

def features
  @features
end

#fingerprintString

The fingerprint of the GTM Container as computed at storage time. This value is recomputed whenever the account is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


382
383
384
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 382

def fingerprint
  @fingerprint
end

#nameString

Container display name. Corresponds to the JSON property name

Returns:

  • (String)


387
388
389
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 387

def name
  @name
end

#notesString

Container Notes. Corresponds to the JSON property notes

Returns:

  • (String)


392
393
394
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 392

def notes
  @notes
end

#pathString

GTM Container's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


397
398
399
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 397

def path
  @path
end

#public_idString

Container Public ID. Corresponds to the JSON property publicId

Returns:

  • (String)


402
403
404
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 402

def public_id
  @public_id
end

#tag_idsArray<String>

All Tag IDs that refer to this Container. Corresponds to the JSON property tagIds

Returns:

  • (Array<String>)


407
408
409
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 407

def tag_ids
  @tag_ids
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


412
413
414
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 412

def tag_manager_url
  @tag_manager_url
end

#tagging_server_urlsArray<String>

List of server-side container URLs for the Container. If multiple URLs are provided, all URL paths must match. Corresponds to the JSON property taggingServerUrls

Returns:

  • (Array<String>)


418
419
420
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 418

def tagging_server_urls
  @tagging_server_urls
end

#usage_contextArray<String>

List of Usage Contexts for the Container. Valid values include: web, android, or ios. Corresponds to the JSON property usageContext

Returns:

  • (Array<String>)


424
425
426
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 424

def usage_context
  @usage_context
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 431

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @container_id = args[:container_id] if args.key?(:container_id)
  @domain_name = args[:domain_name] if args.key?(:domain_name)
  @features = args[:features] if args.key?(:features)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @path = args[:path] if args.key?(:path)
  @public_id = args[:public_id] if args.key?(:public_id)
  @tag_ids = args[:tag_ids] if args.key?(:tag_ids)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @tagging_server_urls = args[:tagging_server_urls] if args.key?(:tagging_server_urls)
  @usage_context = args[:usage_context] if args.key?(:usage_context)
end