Class: Google::Apis::TagmanagerV2::ContainerVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Container Version.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContainerVersion

Returns a new instance of ContainerVersion.



691
692
693
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


591
592
593
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 591

def 
  @account_id
end

#built_in_variableArray<Google::Apis::TagmanagerV2::BuiltInVariable>

The built-in variables in the container that this version was taken from. Corresponds to the JSON property builtInVariable



596
597
598
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 596

def built_in_variable
  @built_in_variable
end

#clientArray<Google::Apis::TagmanagerV2::Client>

The clients in the container that this version was taken from. Corresponds to the JSON property client



601
602
603
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 601

def client
  @client
end

#containerGoogle::Apis::TagmanagerV2::Container

Represents a Google Tag Manager Container, which specifies the platform tags will run on, manages workspaces, and retains container versions. Corresponds to the JSON property container



607
608
609
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 607

def container
  @container
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


612
613
614
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 612

def container_id
  @container_id
end

#container_version_idString

The Container Version ID uniquely identifies the GTM Container Version. Corresponds to the JSON property containerVersionId

Returns:

  • (String)


617
618
619
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 617

def container_version_id
  @container_version_id
end

#custom_templateArray<Google::Apis::TagmanagerV2::CustomTemplate>

The custom templates in the container that this version was taken from. Corresponds to the JSON property customTemplate



622
623
624
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 622

def custom_template
  @custom_template
end

#deletedBoolean Also known as: deleted?

A value of true indicates this container version has been deleted. Corresponds to the JSON property deleted

Returns:

  • (Boolean)


627
628
629
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 627

def deleted
  @deleted
end

#descriptionString

Container version description. Corresponds to the JSON property description

Returns:

  • (String)


633
634
635
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 633

def description
  @description
end

#fingerprintString

The fingerprint of the GTM Container Version as computed at storage time. This value is recomputed whenever the container version is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


639
640
641
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 639

def fingerprint
  @fingerprint
end

#folderArray<Google::Apis::TagmanagerV2::Folder>

The folders in the container that this version was taken from. Corresponds to the JSON property folder



644
645
646
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 644

def folder
  @folder
end

#gtag_configArray<Google::Apis::TagmanagerV2::GtagConfig>

The Google tag configs in the container that this version was taken from. Corresponds to the JSON property gtagConfig



649
650
651
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 649

def gtag_config
  @gtag_config
end

#nameString

Container version display name. Corresponds to the JSON property name

Returns:

  • (String)


654
655
656
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 654

def name
  @name
end

#pathString

GTM Container Version's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


659
660
661
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 659

def path
  @path
end

#tagArray<Google::Apis::TagmanagerV2::Tag>

The tags in the container that this version was taken from. Corresponds to the JSON property tag



664
665
666
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 664

def tag
  @tag
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


669
670
671
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 669

def tag_manager_url
  @tag_manager_url
end

#transformationArray<Google::Apis::TagmanagerV2::Transformation>

The transformations in the container that this version was taken from. Corresponds to the JSON property transformation



674
675
676
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 674

def transformation
  @transformation
end

#triggerArray<Google::Apis::TagmanagerV2::Trigger>

The triggers in the container that this version was taken from. Corresponds to the JSON property trigger



679
680
681
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 679

def trigger
  @trigger
end

#variableArray<Google::Apis::TagmanagerV2::Variable>

The variables in the container that this version was taken from. Corresponds to the JSON property variable



684
685
686
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 684

def variable
  @variable
end

#zoneArray<Google::Apis::TagmanagerV2::Zone>

The zones in the container that this version was taken from. Corresponds to the JSON property zone



689
690
691
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 689

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 696

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @built_in_variable = args[:built_in_variable] if args.key?(:built_in_variable)
  @client = args[:client] if args.key?(:client)
  @container = args[:container] if args.key?(:container)
  @container_id = args[:container_id] if args.key?(:container_id)
  @container_version_id = args[:container_version_id] if args.key?(:container_version_id)
  @custom_template = args[:custom_template] if args.key?(:custom_template)
  @deleted = args[:deleted] if args.key?(:deleted)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @folder = args[:folder] if args.key?(:folder)
  @gtag_config = args[:gtag_config] if args.key?(:gtag_config)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @tag = args[:tag] if args.key?(:tag)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @transformation = args[:transformation] if args.key?(:transformation)
  @trigger = args[:trigger] if args.key?(:trigger)
  @variable = args[:variable] if args.key?(:variable)
  @zone = args[:zone] if args.key?(:zone)
end