Class: Google::Apis::TagmanagerV2::CreateContainerVersionResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Create container versions response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateContainerVersionResponse

Returns a new instance of CreateContainerVersionResponse.



893
894
895
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compiler_errorBoolean Also known as: compiler_error?

Compiler errors or not. Corresponds to the JSON property compilerError

Returns:

  • (Boolean)


869
870
871
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 869

def compiler_error
  @compiler_error
end

#compiler_errorsArray<Google::Apis::TagmanagerV2::CompilerErrorLite>

Compiler error details. Corresponds to the JSON property compilerErrors



875
876
877
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 875

def compiler_errors
  @compiler_errors
end

#container_versionGoogle::Apis::TagmanagerV2::ContainerVersion

Represents a Google Tag Manager Container Version. Corresponds to the JSON property containerVersion



880
881
882
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 880

def container_version
  @container_version
end

#new_workspace_pathString

Auto generated workspace path created as a result of version creation. This field should only be populated if the created version was not a quick preview. Corresponds to the JSON property newWorkspacePath

Returns:

  • (String)


886
887
888
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 886

def new_workspace_path
  @new_workspace_path
end

#sync_statusGoogle::Apis::TagmanagerV2::SyncStatus

The status of a workspace after synchronization. Corresponds to the JSON property syncStatus



891
892
893
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 891

def sync_status
  @sync_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



898
899
900
901
902
903
904
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 898

def update!(**args)
  @compiler_error = args[:compiler_error] if args.key?(:compiler_error)
  @compiler_errors = args[:compiler_errors] if args.key?(:compiler_errors)
  @container_version = args[:container_version] if args.key?(:container_version)
  @new_workspace_path = args[:new_workspace_path] if args.key?(:new_workspace_path)
  @sync_status = args[:sync_status] if args.key?(:sync_status)
end