Class: Google::Apis::TagmanagerV2::CustomTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Custom Template's contents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomTemplate

Returns a new instance of CustomTemplate.



963
964
965
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


914
915
916
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 914

def 
  @account_id
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


919
920
921
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 919

def container_id
  @container_id
end

#fingerprintString

The fingerprint of the GTM Custom Template as computed at storage time. This value is recomputed whenever the template is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


925
926
927
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 925

def fingerprint
  @fingerprint
end

Represents the link between a custom template and an entry on the Community Template Gallery site. Corresponds to the JSON property galleryReference



931
932
933
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 931

def gallery_reference
  @gallery_reference
end

#nameString

Custom Template display name. Corresponds to the JSON property name

Returns:

  • (String)


936
937
938
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 936

def name
  @name
end

#pathString

GTM Custom Template's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


941
942
943
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 941

def path
  @path
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


946
947
948
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 946

def tag_manager_url
  @tag_manager_url
end

#template_dataString

The custom template in text format. Corresponds to the JSON property templateData

Returns:

  • (String)


951
952
953
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 951

def template_data
  @template_data
end

#template_idString

The Custom Template ID uniquely identifies the GTM custom template. Corresponds to the JSON property templateId

Returns:

  • (String)


956
957
958
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 956

def template_id
  @template_id
end

#workspace_idString

GTM Workspace ID. Corresponds to the JSON property workspaceId

Returns:

  • (String)


961
962
963
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 961

def workspace_id
  @workspace_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



968
969
970
971
972
973
974
975
976
977
978
979
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 968

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @container_id = args[:container_id] if args.key?(:container_id)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @gallery_reference = args[:gallery_reference] if args.key?(:gallery_reference)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @template_data = args[:template_data] if args.key?(:template_data)
  @template_id = args[:template_id] if args.key?(:template_id)
  @workspace_id = args[:workspace_id] if args.key?(:workspace_id)
end