Class: Google::Apis::TagmanagerV2::Entity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

A workspace entity that may represent a tag, trigger, variable, or folder in addition to its status in the workspace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Entity

Returns a new instance of Entity.



1107
1108
1109
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#built_in_variableGoogle::Apis::TagmanagerV2::BuiltInVariable

Built-in variables are a special category of variables that are pre-created and non-customizable. They provide common functionality like accessing properties of the gtm data layer, monitoring clicks, or accessing elements of a page URL. Corresponds to the JSON property builtInVariable



1055
1056
1057
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1055

def built_in_variable
  @built_in_variable
end

#change_statusString

Represents how the entity has been changed in the workspace. Corresponds to the JSON property changeStatus

Returns:

  • (String)


1060
1061
1062
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1060

def change_status
  @change_status
end

#clientGoogle::Apis::TagmanagerV2::Client

The client being represented by the entity. Corresponds to the JSON property client



1065
1066
1067
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1065

def client
  @client
end

#custom_templateGoogle::Apis::TagmanagerV2::CustomTemplate

Represents a Google Tag Manager Custom Template's contents. Corresponds to the JSON property customTemplate



1070
1071
1072
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1070

def custom_template
  @custom_template
end

#folderGoogle::Apis::TagmanagerV2::Folder

Represents a Google Tag Manager Folder. Corresponds to the JSON property folder



1075
1076
1077
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1075

def folder
  @folder
end

#gtag_configGoogle::Apis::TagmanagerV2::GtagConfig

Represents a Google tag configuration. Corresponds to the JSON property gtagConfig



1080
1081
1082
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1080

def gtag_config
  @gtag_config
end

#tagGoogle::Apis::TagmanagerV2::Tag

Represents a Google Tag Manager Tag. Corresponds to the JSON property tag



1085
1086
1087
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1085

def tag
  @tag
end

#transformationGoogle::Apis::TagmanagerV2::Transformation

Represents a Google Tag Manager Transformation. Corresponds to the JSON property transformation



1090
1091
1092
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1090

def transformation
  @transformation
end

#triggerGoogle::Apis::TagmanagerV2::Trigger

Represents a Google Tag Manager Trigger Corresponds to the JSON property trigger



1095
1096
1097
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1095

def trigger
  @trigger
end

#variableGoogle::Apis::TagmanagerV2::Variable

Represents a Google Tag Manager Variable. Corresponds to the JSON property variable



1100
1101
1102
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1100

def variable
  @variable
end

#zoneGoogle::Apis::TagmanagerV2::Zone

Represents a Google Tag Manager Zone's contents. Corresponds to the JSON property zone



1105
1106
1107
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1105

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1112

def update!(**args)
  @built_in_variable = args[:built_in_variable] if args.key?(:built_in_variable)
  @change_status = args[:change_status] if args.key?(:change_status)
  @client = args[:client] if args.key?(:client)
  @custom_template = args[:custom_template] if args.key?(:custom_template)
  @folder = args[:folder] if args.key?(:folder)
  @gtag_config = args[:gtag_config] if args.key?(:gtag_config)
  @tag = args[:tag] if args.key?(:tag)
  @transformation = args[:transformation] if args.key?(:transformation)
  @trigger = args[:trigger] if args.key?(:trigger)
  @variable = args[:variable] if args.key?(:variable)
  @zone = args[:zone] if args.key?(:zone)
end