Class: Google::Apis::TagmanagerV2::Environment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Environment. Note that a user can create, delete and update environments of type USER, but can only update the enable_debug and url fields of environments of other types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Environment

Returns a new instance of Environment.



1212
1213
1214
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


1136
1137
1138
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1136

def 
  @account_id
end

#authorization_codeString

The environment authorization code. Corresponds to the JSON property authorizationCode

Returns:

  • (String)


1141
1142
1143
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1141

def authorization_code
  @authorization_code
end

#authorization_timestampString

The last update time-stamp for the authorization code. Corresponds to the JSON property authorizationTimestamp

Returns:

  • (String)


1146
1147
1148
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1146

def authorization_timestamp
  @authorization_timestamp
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


1151
1152
1153
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1151

def container_id
  @container_id
end

#container_version_idString

Represents a link to a container version. Corresponds to the JSON property containerVersionId

Returns:

  • (String)


1156
1157
1158
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1156

def container_version_id
  @container_version_id
end

#descriptionString

The environment description. Can be set or changed only on USER type environments. Corresponds to the JSON property description

Returns:

  • (String)


1162
1163
1164
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1162

def description
  @description
end

#enable_debugBoolean Also known as: enable_debug?

Whether or not to enable debug by default for the environment. Corresponds to the JSON property enableDebug

Returns:

  • (Boolean)


1167
1168
1169
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1167

def enable_debug
  @enable_debug
end

#environment_idString

GTM Environment ID uniquely identifies the GTM Environment. Corresponds to the JSON property environmentId

Returns:

  • (String)


1173
1174
1175
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1173

def environment_id
  @environment_id
end

#fingerprintString

The fingerprint of the GTM environment as computed at storage time. This value is recomputed whenever the environment is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


1179
1180
1181
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1179

def fingerprint
  @fingerprint
end

#nameString

The environment display name. Can be set or changed only on USER type environments. Corresponds to the JSON property name

Returns:

  • (String)


1185
1186
1187
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1185

def name
  @name
end

#pathString

GTM Environment's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


1190
1191
1192
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1190

def path
  @path
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


1195
1196
1197
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1195

def tag_manager_url
  @tag_manager_url
end

#typeString

The type of this environment. Corresponds to the JSON property type

Returns:

  • (String)


1200
1201
1202
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1200

def type
  @type
end

#urlString

Default preview page url for the environment. Corresponds to the JSON property url

Returns:

  • (String)


1205
1206
1207
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1205

def url
  @url
end

#workspace_idString

Represents a link to a quick preview of a workspace. Corresponds to the JSON property workspaceId

Returns:

  • (String)


1210
1211
1212
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1210

def workspace_id
  @workspace_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1217

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @authorization_code = args[:authorization_code] if args.key?(:authorization_code)
  @authorization_timestamp = args[:authorization_timestamp] if args.key?(:authorization_timestamp)
  @container_id = args[:container_id] if args.key?(:container_id)
  @container_version_id = args[:container_version_id] if args.key?(:container_version_id)
  @description = args[:description] if args.key?(:description)
  @enable_debug = args[:enable_debug] if args.key?(:enable_debug)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
  @workspace_id = args[:workspace_id] if args.key?(:workspace_id)
end