Class: Google::Apis::TagmanagerV2::Folder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Folder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Folder

Returns a new instance of Folder.



1286
1287
1288
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


1243
1244
1245
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1243

def 
  @account_id
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1248

def container_id
  @container_id
end

#fingerprintString

The fingerprint of the GTM Folder as computed at storage time. This value is recomputed whenever the folder is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


1254
1255
1256
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1254

def fingerprint
  @fingerprint
end

#folder_idString

The Folder ID uniquely identifies the GTM Folder. Corresponds to the JSON property folderId

Returns:

  • (String)


1259
1260
1261
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1259

def folder_id
  @folder_id
end

#nameString

Folder display name. Corresponds to the JSON property name

Returns:

  • (String)


1264
1265
1266
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1264

def name
  @name
end

#notesString

User notes on how to apply this folder in the container. Corresponds to the JSON property notes

Returns:

  • (String)


1269
1270
1271
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1269

def notes
  @notes
end

#pathString

GTM Folder's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


1274
1275
1276
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1274

def path
  @path
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


1279
1280
1281
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1279

def tag_manager_url
  @tag_manager_url
end

#workspace_idString

GTM Workspace ID. Corresponds to the JSON property workspaceId

Returns:

  • (String)


1284
1285
1286
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1284

def workspace_id
  @workspace_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1291

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @container_id = args[:container_id] if args.key?(:container_id)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @folder_id = args[:folder_id] if args.key?(:folder_id)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @path = args[:path] if args.key?(:path)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @workspace_id = args[:workspace_id] if args.key?(:workspace_id)
end