Class: Google::Apis::TagmanagerV2::GetContainerSnippetResponse
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::GetContainerSnippetResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Instance Attribute Summary collapse
-
#container_config ⇒ String
Server container config param for manually provisioning a tagging server.
-
#snippet ⇒ String
Tagging snippet for a Container.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetContainerSnippetResponse
constructor
A new instance of GetContainerSnippetResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetContainerSnippetResponse
Returns a new instance of GetContainerSnippetResponse.
1390 1391 1392 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_config ⇒ String
Server container config param for manually provisioning a tagging server.
Corresponds to the JSON property containerConfig
1383 1384 1385 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1383 def container_config @container_config end |
#snippet ⇒ String
Tagging snippet for a Container.
Corresponds to the JSON property snippet
1388 1389 1390 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1388 def snippet @snippet end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1395 1396 1397 1398 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1395 def update!(**args) @container_config = args[:container_config] if args.key?(:container_config) @snippet = args[:snippet] if args.key?(:snippet) end |