Class: Google::Apis::TagmanagerV2::GtagConfig
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::GtagConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google tag configuration.
Instance Attribute Summary collapse
-
#account_id ⇒ String
Google tag account ID.
-
#container_id ⇒ String
Google tag container ID.
-
#fingerprint ⇒ String
The fingerprint of the Google tag config as computed at storage time.
-
#gtag_config_id ⇒ String
The ID uniquely identifies the Google tag config.
-
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The Google tag config's parameters.
-
#path ⇒ String
Google tag config's API relative path.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#type ⇒ String
Google tag config type.
-
#workspace_id ⇒ String
Google tag workspace ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GtagConfig
constructor
A new instance of GtagConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GtagConfig
Returns a new instance of GtagConfig.
1508 1509 1510 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
Google tag account ID.
Corresponds to the JSON property accountId
1465 1466 1467 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1465 def account_id @account_id end |
#container_id ⇒ String
Google tag container ID.
Corresponds to the JSON property containerId
1470 1471 1472 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1470 def container_id @container_id end |
#fingerprint ⇒ String
The fingerprint of the Google tag config as computed at storage time. This
value is recomputed whenever the config is modified.
Corresponds to the JSON property fingerprint
1476 1477 1478 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1476 def fingerprint @fingerprint end |
#gtag_config_id ⇒ String
The ID uniquely identifies the Google tag config.
Corresponds to the JSON property gtagConfigId
1481 1482 1483 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1481 def gtag_config_id @gtag_config_id end |
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The Google tag config's parameters.
Corresponds to the JSON property parameter
1486 1487 1488 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1486 def parameter @parameter end |
#path ⇒ String
Google tag config's API relative path.
Corresponds to the JSON property path
1491 1492 1493 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1491 def path @path end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
1496 1497 1498 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1496 def tag_manager_url @tag_manager_url end |
#type ⇒ String
Google tag config type.
Corresponds to the JSON property type
1501 1502 1503 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1501 def type @type end |
#workspace_id ⇒ String
Google tag workspace ID. Only used by GTM containers. Set to 0 otherwise.
Corresponds to the JSON property workspaceId
1506 1507 1508 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1506 def workspace_id @workspace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1513 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container_id = args[:container_id] if args.key?(:container_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @gtag_config_id = args[:gtag_config_id] if args.key?(:gtag_config_id) @parameter = args[:parameter] if args.key?(:parameter) @path = args[:path] if args.key?(:path) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @type = args[:type] if args.key?(:type) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) end |