Class: Google::Apis::TagmanagerV2::MergeConflict

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a merge conflict.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MergeConflict

Returns a new instance of MergeConflict.



1967
1968
1969
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_in_base_versionGoogle::Apis::TagmanagerV2::Entity

A workspace entity that may represent a tag, trigger, variable, or folder in addition to its status in the workspace. Corresponds to the JSON property entityInBaseVersion



1959
1960
1961
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1959

def entity_in_base_version
  @entity_in_base_version
end

#entity_in_workspaceGoogle::Apis::TagmanagerV2::Entity

A workspace entity that may represent a tag, trigger, variable, or folder in addition to its status in the workspace. Corresponds to the JSON property entityInWorkspace



1965
1966
1967
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1965

def entity_in_workspace
  @entity_in_workspace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1972
1973
1974
1975
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1972

def update!(**args)
  @entity_in_base_version = args[:entity_in_base_version] if args.key?(:entity_in_base_version)
  @entity_in_workspace = args[:entity_in_workspace] if args.key?(:entity_in_workspace)
end