Class: Google::Apis::TagmanagerV2::RevertClientResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

The result of reverting a client in a workspace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevertClientResponse

Returns a new instance of RevertClientResponse.



2158
2159
2160
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2158

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clientGoogle::Apis::TagmanagerV2::Client

Client as it appears in the latest container version since the last workspace synchronization operation. If no client is present, that means the client was deleted in the latest container version. Corresponds to the JSON property client



2156
2157
2158
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2156

def client
  @client
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2163
2164
2165
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2163

def update!(**args)
  @client = args[:client] if args.key?(:client)
end