Class: Google::Apis::TagmanagerV2::RevertTriggerResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

The result of reverting a trigger in a workspace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RevertTriggerResponse

Returns a new instance of RevertTriggerResponse.



2210
2211
2212
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#triggerGoogle::Apis::TagmanagerV2::Trigger

Represents a Google Tag Manager Trigger Corresponds to the JSON property trigger



2208
2209
2210
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2208

def trigger
  @trigger
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2215
2216
2217
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2215

def update!(**args)
  @trigger = args[:trigger] if args.key?(:trigger)
end