Class: Google::Apis::TagmanagerV2::SetupTag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a reference to atag that fires before another tag in order to set up dependencies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetupTag

Returns a new instance of SetupTag.



2318
2319
2320
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stop_on_setup_failureBoolean Also known as: stop_on_setup_failure?

If true, fire the main tag if and only if the setup tag fires successfully. If false, fire the main tag regardless of setup tag firing status. Corresponds to the JSON property stopOnSetupFailure

Returns:

  • (Boolean)


2310
2311
2312
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2310

def stop_on_setup_failure
  @stop_on_setup_failure
end

#tag_nameString

The name of the setup tag. Corresponds to the JSON property tagName

Returns:

  • (String)


2316
2317
2318
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2316

def tag_name
  @tag_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2323
2324
2325
2326
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2323

def update!(**args)
  @stop_on_setup_failure = args[:stop_on_setup_failure] if args.key?(:stop_on_setup_failure)
  @tag_name = args[:tag_name] if args.key?(:tag_name)
end