Class: Google::Apis::TagmanagerV2::TeardownTag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a tag that fires after another tag in order to tear down dependencies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TeardownTag

Returns a new instance of TeardownTag.



2596
2597
2598
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stop_teardown_on_failureBoolean Also known as: stop_teardown_on_failure?

If true, fire the teardown tag if and only if the main tag fires successfully. If false, fire the teardown tag regardless of main tag firing status. Corresponds to the JSON property stopTeardownOnFailure

Returns:

  • (Boolean)


2588
2589
2590
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2588

def stop_teardown_on_failure
  @stop_teardown_on_failure
end

#tag_nameString

The name of the teardown tag. Corresponds to the JSON property tagName

Returns:

  • (String)


2594
2595
2596
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2594

def tag_name
  @tag_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2601
2602
2603
2604
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2601

def update!(**args)
  @stop_teardown_on_failure = args[:stop_teardown_on_failure] if args.key?(:stop_teardown_on_failure)
  @tag_name = args[:tag_name] if args.key?(:tag_name)
end