Class: Google::Apis::TagmanagerV2::Trigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Trigger

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Trigger

Returns a new instance of Trigger.



2858
2859
2860
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


2700
2701
2702
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2700

def 
  @account_id
end

#auto_event_filterArray<Google::Apis::TagmanagerV2::Condition>

Used in the case of auto event tracking. Corresponds to the JSON property autoEventFilter



2705
2706
2707
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2705

def auto_event_filter
  @auto_event_filter
end

#check_validationGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property checkValidation



2710
2711
2712
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2710

def check_validation
  @check_validation
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


2715
2716
2717
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2715

def container_id
  @container_id
end

#continuous_time_min_millisecondsGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property continuousTimeMinMilliseconds



2720
2721
2722
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2720

def continuous_time_min_milliseconds
  @continuous_time_min_milliseconds
end

#custom_event_filterArray<Google::Apis::TagmanagerV2::Condition>

Used in the case of custom event, which is fired iff all Conditions are true. Corresponds to the JSON property customEventFilter



2725
2726
2727
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2725

def custom_event_filter
  @custom_event_filter
end

#event_nameGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property eventName



2730
2731
2732
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2730

def event_name
  @event_name
end

#filterArray<Google::Apis::TagmanagerV2::Condition>

The trigger will only fire iff all Conditions are true. Corresponds to the JSON property filter



2735
2736
2737
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2735

def filter
  @filter
end

#fingerprintString

The fingerprint of the GTM Trigger as computed at storage time. This value is recomputed whenever the trigger is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


2741
2742
2743
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2741

def fingerprint
  @fingerprint
end

#horizontal_scroll_percentage_listGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property horizontalScrollPercentageList



2746
2747
2748
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2746

def horizontal_scroll_percentage_list
  @horizontal_scroll_percentage_list
end

#intervalGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property interval



2751
2752
2753
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2751

def interval
  @interval
end

#interval_secondsGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property intervalSeconds



2756
2757
2758
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2756

def interval_seconds
  @interval_seconds
end

#limitGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property limit



2761
2762
2763
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2761

def limit
  @limit
end

#max_timer_length_secondsGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property maxTimerLengthSeconds



2766
2767
2768
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2766

def max_timer_length_seconds
  @max_timer_length_seconds
end

#nameString

Trigger display name. Corresponds to the JSON property name

Returns:

  • (String)


2771
2772
2773
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2771

def name
  @name
end

#notesString

User notes on how to apply this trigger in the container. Corresponds to the JSON property notes

Returns:

  • (String)


2776
2777
2778
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2776

def notes
  @notes
end

#parameterArray<Google::Apis::TagmanagerV2::Parameter>

Additional parameters. Corresponds to the JSON property parameter



2781
2782
2783
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2781

def parameter
  @parameter
end

#parent_folder_idString

Parent folder id. Corresponds to the JSON property parentFolderId

Returns:

  • (String)


2786
2787
2788
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2786

def parent_folder_id
  @parent_folder_id
end

#pathString

GTM Trigger's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


2791
2792
2793
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2791

def path
  @path
end

#selectorGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property selector



2796
2797
2798
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2796

def selector
  @selector
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


2801
2802
2803
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2801

def tag_manager_url
  @tag_manager_url
end

#total_time_min_millisecondsGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property totalTimeMinMilliseconds



2806
2807
2808
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2806

def total_time_min_milliseconds
  @total_time_min_milliseconds
end

#trigger_idString

The Trigger ID uniquely identifies the GTM Trigger. Corresponds to the JSON property triggerId

Returns:

  • (String)


2811
2812
2813
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2811

def trigger_id
  @trigger_id
end

#typeString

Defines the data layer event that causes this trigger. Corresponds to the JSON property type

Returns:

  • (String)


2816
2817
2818
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2816

def type
  @type
end

#unique_trigger_idGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property uniqueTriggerId



2821
2822
2823
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2821

def unique_trigger_id
  @unique_trigger_id
end

#vertical_scroll_percentage_listGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property verticalScrollPercentageList



2826
2827
2828
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2826

def vertical_scroll_percentage_list
  @vertical_scroll_percentage_list
end

#visibility_selectorGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property visibilitySelector



2831
2832
2833
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2831

def visibility_selector
  @visibility_selector
end

#visible_percentage_maxGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property visiblePercentageMax



2836
2837
2838
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2836

def visible_percentage_max
  @visible_percentage_max
end

#visible_percentage_minGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property visiblePercentageMin



2841
2842
2843
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2841

def visible_percentage_min
  @visible_percentage_min
end

#wait_for_tagsGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property waitForTags



2846
2847
2848
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2846

def wait_for_tags
  @wait_for_tags
end

#wait_for_tags_timeoutGoogle::Apis::TagmanagerV2::Parameter

Represents a Google Tag Manager Parameter. Corresponds to the JSON property waitForTagsTimeout



2851
2852
2853
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2851

def wait_for_tags_timeout
  @wait_for_tags_timeout
end

#workspace_idString

GTM Workspace ID. Corresponds to the JSON property workspaceId

Returns:

  • (String)


2856
2857
2858
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2856

def workspace_id
  @workspace_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2863
2864
2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
2875
2876
2877
2878
2879
2880
2881
2882
2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
2894
2895
2896
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2863

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @auto_event_filter = args[:auto_event_filter] if args.key?(:auto_event_filter)
  @check_validation = args[:check_validation] if args.key?(:check_validation)
  @container_id = args[:container_id] if args.key?(:container_id)
  @continuous_time_min_milliseconds = args[:continuous_time_min_milliseconds] if args.key?(:continuous_time_min_milliseconds)
  @custom_event_filter = args[:custom_event_filter] if args.key?(:custom_event_filter)
  @event_name = args[:event_name] if args.key?(:event_name)
  @filter = args[:filter] if args.key?(:filter)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @horizontal_scroll_percentage_list = args[:horizontal_scroll_percentage_list] if args.key?(:horizontal_scroll_percentage_list)
  @interval = args[:interval] if args.key?(:interval)
  @interval_seconds = args[:interval_seconds] if args.key?(:interval_seconds)
  @limit = args[:limit] if args.key?(:limit)
  @max_timer_length_seconds = args[:max_timer_length_seconds] if args.key?(:max_timer_length_seconds)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @parameter = args[:parameter] if args.key?(:parameter)
  @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id)
  @path = args[:path] if args.key?(:path)
  @selector = args[:selector] if args.key?(:selector)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @total_time_min_milliseconds = args[:total_time_min_milliseconds] if args.key?(:total_time_min_milliseconds)
  @trigger_id = args[:trigger_id] if args.key?(:trigger_id)
  @type = args[:type] if args.key?(:type)
  @unique_trigger_id = args[:unique_trigger_id] if args.key?(:unique_trigger_id)
  @vertical_scroll_percentage_list = args[:vertical_scroll_percentage_list] if args.key?(:vertical_scroll_percentage_list)
  @visibility_selector = args[:visibility_selector] if args.key?(:visibility_selector)
  @visible_percentage_max = args[:visible_percentage_max] if args.key?(:visible_percentage_max)
  @visible_percentage_min = args[:visible_percentage_min] if args.key?(:visible_percentage_min)
  @wait_for_tags = args[:wait_for_tags] if args.key?(:wait_for_tags)
  @wait_for_tags_timeout = args[:wait_for_tags_timeout] if args.key?(:wait_for_tags_timeout)
  @workspace_id = args[:workspace_id] if args.key?(:workspace_id)
end