Class: Google::Apis::TagmanagerV2::Zone
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Zone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Zone's contents.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#boundary ⇒ Google::Apis::TagmanagerV2::ZoneBoundary
Represents a Zone's boundaries.
-
#child_container ⇒ Array<Google::Apis::TagmanagerV2::ZoneChildContainer>
Containers that are children of this Zone.
-
#container_id ⇒ String
GTM Container ID.
-
#fingerprint ⇒ String
The fingerprint of the GTM Zone as computed at storage time.
-
#name ⇒ String
Zone display name.
-
#notes ⇒ String
User notes on how to apply this zone in the container.
-
#path ⇒ String
GTM Zone's API relative path.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#type_restriction ⇒ Google::Apis::TagmanagerV2::ZoneTypeRestriction
Represents a Zone's type restrictions.
-
#workspace_id ⇒ String
GTM Workspace ID.
-
#zone_id ⇒ String
The Zone ID uniquely identifies the GTM Zone.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Zone
constructor
A new instance of Zone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Zone
Returns a new instance of Zone.
3203 3204 3205 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
3145 3146 3147 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3145 def account_id @account_id end |
#boundary ⇒ Google::Apis::TagmanagerV2::ZoneBoundary
Represents a Zone's boundaries.
Corresponds to the JSON property boundary
3150 3151 3152 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3150 def boundary @boundary end |
#child_container ⇒ Array<Google::Apis::TagmanagerV2::ZoneChildContainer>
Containers that are children of this Zone.
Corresponds to the JSON property childContainer
3155 3156 3157 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3155 def child_container @child_container end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
3160 3161 3162 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3160 def container_id @container_id end |
#fingerprint ⇒ String
The fingerprint of the GTM Zone as computed at storage time. This value is
recomputed whenever the zone is modified.
Corresponds to the JSON property fingerprint
3166 3167 3168 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3166 def fingerprint @fingerprint end |
#name ⇒ String
Zone display name.
Corresponds to the JSON property name
3171 3172 3173 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3171 def name @name end |
#notes ⇒ String
User notes on how to apply this zone in the container.
Corresponds to the JSON property notes
3176 3177 3178 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3176 def notes @notes end |
#path ⇒ String
GTM Zone's API relative path.
Corresponds to the JSON property path
3181 3182 3183 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3181 def path @path end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
3186 3187 3188 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3186 def tag_manager_url @tag_manager_url end |
#type_restriction ⇒ Google::Apis::TagmanagerV2::ZoneTypeRestriction
Represents a Zone's type restrictions.
Corresponds to the JSON property typeRestriction
3191 3192 3193 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3191 def type_restriction @type_restriction end |
#workspace_id ⇒ String
GTM Workspace ID.
Corresponds to the JSON property workspaceId
3196 3197 3198 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3196 def workspace_id @workspace_id end |
#zone_id ⇒ String
The Zone ID uniquely identifies the GTM Zone.
Corresponds to the JSON property zoneId
3201 3202 3203 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3201 def zone_id @zone_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3208 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @boundary = args[:boundary] if args.key?(:boundary) @child_container = args[:child_container] if args.key?(:child_container) @container_id = args[:container_id] if args.key?(:container_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @path = args[:path] if args.key?(:path) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @type_restriction = args[:type_restriction] if args.key?(:type_restriction) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) @zone_id = args[:zone_id] if args.key?(:zone_id) end |