Class: Google::Apis::TagmanagerV2::ZoneBoundary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Zone's boundaries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneBoundary

Returns a new instance of ZoneBoundary.



3239
3240
3241
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionArray<Google::Apis::TagmanagerV2::Condition>

The conditions that, when conjoined, make up the boundary. Corresponds to the JSON property condition



3231
3232
3233
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3231

def condition
  @condition
end

#custom_evaluation_trigger_idArray<String>

Custom evaluation trigger IDs. A zone will evaluate its boundary conditions when any of the listed triggers are true. Corresponds to the JSON property customEvaluationTriggerId

Returns:

  • (Array<String>)


3237
3238
3239
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3237

def custom_evaluation_trigger_id
  @custom_evaluation_trigger_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3244
3245
3246
3247
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3244

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @custom_evaluation_trigger_id = args[:custom_evaluation_trigger_id] if args.key?(:custom_evaluation_trigger_id)
end