Class: Google::Apis::TagmanagerV2::Container
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Container
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Container, which specifies the platform tags will run on, manages workspaces, and retains container versions.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#container_id ⇒ String
The Container ID uniquely identifies the GTM Container.
-
#domain_name ⇒ Array<String>
List of domain names associated with the Container.
-
#features ⇒ Google::Apis::TagmanagerV2::ContainerFeatures
Read-only Container feature set.
-
#fingerprint ⇒ String
The fingerprint of the GTM Container as computed at storage time.
-
#name ⇒ String
Container display name.
-
#notes ⇒ String
Container Notes.
-
#path ⇒ String
GTM Container's API relative path.
-
#public_id ⇒ String
Container Public ID.
-
#tag_ids ⇒ Array<String>
All Tag IDs that refer to this Container.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#tagging_server_urls ⇒ Array<String>
List of server-side container URLs for the Container.
-
#usage_context ⇒ Array<String>
List of Usage Contexts for the Container.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Container
constructor
A new instance of Container.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Container
Returns a new instance of Container.
401 402 403 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
336 337 338 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 336 def account_id @account_id end |
#container_id ⇒ String
The Container ID uniquely identifies the GTM Container.
Corresponds to the JSON property containerId
341 342 343 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 341 def container_id @container_id end |
#domain_name ⇒ Array<String>
List of domain names associated with the Container.
Corresponds to the JSON property domainName
346 347 348 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 346 def domain_name @domain_name end |
#features ⇒ Google::Apis::TagmanagerV2::ContainerFeatures
Read-only Container feature set.
Corresponds to the JSON property features
351 352 353 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 351 def features @features end |
#fingerprint ⇒ String
The fingerprint of the GTM Container as computed at storage time. This value
is recomputed whenever the account is modified.
Corresponds to the JSON property fingerprint
357 358 359 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 357 def fingerprint @fingerprint end |
#name ⇒ String
Container display name.
Corresponds to the JSON property name
362 363 364 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 362 def name @name end |
#notes ⇒ String
Container Notes.
Corresponds to the JSON property notes
367 368 369 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 367 def notes @notes end |
#path ⇒ String
GTM Container's API relative path.
Corresponds to the JSON property path
372 373 374 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 372 def path @path end |
#public_id ⇒ String
Container Public ID.
Corresponds to the JSON property publicId
377 378 379 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 377 def public_id @public_id end |
#tag_ids ⇒ Array<String>
All Tag IDs that refer to this Container.
Corresponds to the JSON property tagIds
382 383 384 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 382 def tag_ids @tag_ids end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
387 388 389 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 387 def tag_manager_url @tag_manager_url end |
#tagging_server_urls ⇒ Array<String>
List of server-side container URLs for the Container. If multiple URLs are
provided, all URL paths must match.
Corresponds to the JSON property taggingServerUrls
393 394 395 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 393 def tagging_server_urls @tagging_server_urls end |
#usage_context ⇒ Array<String>
List of Usage Contexts for the Container. Valid values include: web, android,
or ios.
Corresponds to the JSON property usageContext
399 400 401 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 399 def usage_context @usage_context end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 406 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container_id = args[:container_id] if args.key?(:container_id) @domain_name = args[:domain_name] if args.key?(:domain_name) @features = args[:features] if args.key?(:features) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @path = args[:path] if args.key?(:path) @public_id = args[:public_id] if args.key?(:public_id) @tag_ids = args[:tag_ids] if args.key?(:tag_ids) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @tagging_server_urls = args[:tagging_server_urls] if args.key?(:tagging_server_urls) @usage_context = args[:usage_context] if args.key?(:usage_context) end |