Class: Google::Apis::TagmanagerV2::ContainerVersion
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::ContainerVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Container Version.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#built_in_variable ⇒ Array<Google::Apis::TagmanagerV2::BuiltInVariable>
The built-in variables in the container that this version was taken from.
-
#client ⇒ Array<Google::Apis::TagmanagerV2::Client>
The clients in the container that this version was taken from.
-
#container ⇒ Google::Apis::TagmanagerV2::Container
Represents a Google Tag Manager Container, which specifies the platform tags will run on, manages workspaces, and retains container versions.
-
#container_id ⇒ String
GTM Container ID.
-
#container_version_id ⇒ String
The Container Version ID uniquely identifies the GTM Container Version.
-
#custom_template ⇒ Array<Google::Apis::TagmanagerV2::CustomTemplate>
The custom templates in the container that this version was taken from.
-
#deleted ⇒ Boolean
(also: #deleted?)
A value of true indicates this container version has been deleted.
-
#description ⇒ String
Container version description.
-
#fingerprint ⇒ String
The fingerprint of the GTM Container Version as computed at storage time.
-
#folder ⇒ Array<Google::Apis::TagmanagerV2::Folder>
The folders in the container that this version was taken from.
-
#gtag_config ⇒ Array<Google::Apis::TagmanagerV2::GtagConfig>
The Google tag configs in the container that this version was taken from.
-
#name ⇒ String
Container version display name.
-
#path ⇒ String
GTM Container Version's API relative path.
-
#tag ⇒ Array<Google::Apis::TagmanagerV2::Tag>
The tags in the container that this version was taken from.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#transformation ⇒ Array<Google::Apis::TagmanagerV2::Transformation>
The transformations in the container that this version was taken from.
-
#trigger ⇒ Array<Google::Apis::TagmanagerV2::Trigger>
The triggers in the container that this version was taken from.
-
#variable ⇒ Array<Google::Apis::TagmanagerV2::Variable>
The variables in the container that this version was taken from.
-
#zone ⇒ Array<Google::Apis::TagmanagerV2::Zone>
The zones in the container that this version was taken from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContainerVersion
constructor
A new instance of ContainerVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContainerVersion
Returns a new instance of ContainerVersion.
666 667 668 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 666 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
566 567 568 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 566 def account_id @account_id end |
#built_in_variable ⇒ Array<Google::Apis::TagmanagerV2::BuiltInVariable>
The built-in variables in the container that this version was taken from.
Corresponds to the JSON property builtInVariable
571 572 573 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 571 def built_in_variable @built_in_variable end |
#client ⇒ Array<Google::Apis::TagmanagerV2::Client>
The clients in the container that this version was taken from.
Corresponds to the JSON property client
576 577 578 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 576 def client @client end |
#container ⇒ Google::Apis::TagmanagerV2::Container
Represents a Google Tag Manager Container, which specifies the platform tags
will run on, manages workspaces, and retains container versions.
Corresponds to the JSON property container
582 583 584 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 582 def container @container end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
587 588 589 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 587 def container_id @container_id end |
#container_version_id ⇒ String
The Container Version ID uniquely identifies the GTM Container Version.
Corresponds to the JSON property containerVersionId
592 593 594 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 592 def container_version_id @container_version_id end |
#custom_template ⇒ Array<Google::Apis::TagmanagerV2::CustomTemplate>
The custom templates in the container that this version was taken from.
Corresponds to the JSON property customTemplate
597 598 599 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 597 def custom_template @custom_template end |
#deleted ⇒ Boolean Also known as: deleted?
A value of true indicates this container version has been deleted.
Corresponds to the JSON property deleted
602 603 604 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 602 def deleted @deleted end |
#description ⇒ String
Container version description.
Corresponds to the JSON property description
608 609 610 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 608 def description @description end |
#fingerprint ⇒ String
The fingerprint of the GTM Container Version as computed at storage time. This
value is recomputed whenever the container version is modified.
Corresponds to the JSON property fingerprint
614 615 616 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 614 def fingerprint @fingerprint end |
#folder ⇒ Array<Google::Apis::TagmanagerV2::Folder>
The folders in the container that this version was taken from.
Corresponds to the JSON property folder
619 620 621 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 619 def folder @folder end |
#gtag_config ⇒ Array<Google::Apis::TagmanagerV2::GtagConfig>
The Google tag configs in the container that this version was taken from.
Corresponds to the JSON property gtagConfig
624 625 626 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 624 def gtag_config @gtag_config end |
#name ⇒ String
Container version display name.
Corresponds to the JSON property name
629 630 631 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 629 def name @name end |
#path ⇒ String
GTM Container Version's API relative path.
Corresponds to the JSON property path
634 635 636 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 634 def path @path end |
#tag ⇒ Array<Google::Apis::TagmanagerV2::Tag>
The tags in the container that this version was taken from.
Corresponds to the JSON property tag
639 640 641 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 639 def tag @tag end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
644 645 646 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 644 def tag_manager_url @tag_manager_url end |
#transformation ⇒ Array<Google::Apis::TagmanagerV2::Transformation>
The transformations in the container that this version was taken from.
Corresponds to the JSON property transformation
649 650 651 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 649 def transformation @transformation end |
#trigger ⇒ Array<Google::Apis::TagmanagerV2::Trigger>
The triggers in the container that this version was taken from.
Corresponds to the JSON property trigger
654 655 656 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 654 def trigger @trigger end |
#variable ⇒ Array<Google::Apis::TagmanagerV2::Variable>
The variables in the container that this version was taken from.
Corresponds to the JSON property variable
659 660 661 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 659 def variable @variable end |
#zone ⇒ Array<Google::Apis::TagmanagerV2::Zone>
The zones in the container that this version was taken from.
Corresponds to the JSON property zone
664 665 666 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 664 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 671 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @built_in_variable = args[:built_in_variable] if args.key?(:built_in_variable) @client = args[:client] if args.key?(:client) @container = args[:container] if args.key?(:container) @container_id = args[:container_id] if args.key?(:container_id) @container_version_id = args[:container_version_id] if args.key?(:container_version_id) @custom_template = args[:custom_template] if args.key?(:custom_template) @deleted = args[:deleted] if args.key?(:deleted) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @folder = args[:folder] if args.key?(:folder) @gtag_config = args[:gtag_config] if args.key?(:gtag_config) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @tag = args[:tag] if args.key?(:tag) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @transformation = args[:transformation] if args.key?(:transformation) @trigger = args[:trigger] if args.key?(:trigger) @variable = args[:variable] if args.key?(:variable) @zone = args[:zone] if args.key?(:zone) end |