Class: Google::Apis::TagmanagerV2::Destination
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Destination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Destination.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#container_id ⇒ String
GTM Container ID.
-
#destination_id ⇒ String
Destination ID.
-
#destination_link_id ⇒ String
The Destination link ID uniquely identifies the Destination.
-
#fingerprint ⇒ String
The fingerprint of the Google Tag Destination as computed at storage time.
-
#name ⇒ String
Destination display name.
-
#path ⇒ String
Destination's API relative path.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Destination
constructor
A new instance of Destination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Destination
Returns a new instance of Destination.
1027 1028 1029 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1027 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
989 990 991 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 989 def account_id @account_id end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
994 995 996 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 994 def container_id @container_id end |
#destination_id ⇒ String
Destination ID.
Corresponds to the JSON property destinationId
999 1000 1001 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 999 def destination_id @destination_id end |
#destination_link_id ⇒ String
The Destination link ID uniquely identifies the Destination.
Corresponds to the JSON property destinationLinkId
1004 1005 1006 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1004 def destination_link_id @destination_link_id end |
#fingerprint ⇒ String
The fingerprint of the Google Tag Destination as computed at storage time.
This value is recomputed whenever the destination is modified.
Corresponds to the JSON property fingerprint
1010 1011 1012 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1010 def fingerprint @fingerprint end |
#name ⇒ String
Destination display name.
Corresponds to the JSON property name
1015 1016 1017 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1015 def name @name end |
#path ⇒ String
Destination's API relative path.
Corresponds to the JSON property path
1020 1021 1022 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1020 def path @path end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI.
Corresponds to the JSON property tagManagerUrl
1025 1026 1027 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1025 def tag_manager_url @tag_manager_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1032 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container_id = args[:container_id] if args.key?(:container_id) @destination_id = args[:destination_id] if args.key?(:destination_id) @destination_link_id = args[:destination_link_id] if args.key?(:destination_link_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) end |