Class: Google::Apis::TagmanagerV2::Environment
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Environment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Environment. Note that a user can create, delete and update environments of type USER, but can only update the enable_debug and url fields of environments of other types.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#authorization_code ⇒ String
The environment authorization code.
-
#authorization_timestamp ⇒ String
The last update time-stamp for the authorization code.
-
#container_id ⇒ String
GTM Container ID.
-
#container_version_id ⇒ String
Represents a link to a container version.
-
#description ⇒ String
The environment description.
-
#enable_debug ⇒ Boolean
(also: #enable_debug?)
Whether or not to enable debug by default for the environment.
-
#environment_id ⇒ String
GTM Environment ID uniquely identifies the GTM Environment.
-
#fingerprint ⇒ String
The fingerprint of the GTM environment as computed at storage time.
-
#name ⇒ String
The environment display name.
-
#path ⇒ String
GTM Environment's API relative path.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#type ⇒ String
The type of this environment.
-
#url ⇒ String
Default preview page url for the environment.
-
#workspace_id ⇒ String
Represents a link to a quick preview of a workspace.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Environment
constructor
A new instance of Environment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Environment
Returns a new instance of Environment.
1181 1182 1183 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
1105 1106 1107 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1105 def account_id @account_id end |
#authorization_code ⇒ String
The environment authorization code.
Corresponds to the JSON property authorizationCode
1110 1111 1112 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1110 def @authorization_code end |
#authorization_timestamp ⇒ String
The last update time-stamp for the authorization code.
Corresponds to the JSON property authorizationTimestamp
1115 1116 1117 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1115 def @authorization_timestamp end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
1120 1121 1122 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1120 def container_id @container_id end |
#container_version_id ⇒ String
Represents a link to a container version.
Corresponds to the JSON property containerVersionId
1125 1126 1127 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1125 def container_version_id @container_version_id end |
#description ⇒ String
The environment description. Can be set or changed only on USER type
environments.
Corresponds to the JSON property description
1131 1132 1133 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1131 def description @description end |
#enable_debug ⇒ Boolean Also known as: enable_debug?
Whether or not to enable debug by default for the environment.
Corresponds to the JSON property enableDebug
1136 1137 1138 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1136 def enable_debug @enable_debug end |
#environment_id ⇒ String
GTM Environment ID uniquely identifies the GTM Environment.
Corresponds to the JSON property environmentId
1142 1143 1144 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1142 def environment_id @environment_id end |
#fingerprint ⇒ String
The fingerprint of the GTM environment as computed at storage time. This value
is recomputed whenever the environment is modified.
Corresponds to the JSON property fingerprint
1148 1149 1150 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1148 def fingerprint @fingerprint end |
#name ⇒ String
The environment display name. Can be set or changed only on USER type
environments.
Corresponds to the JSON property name
1154 1155 1156 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1154 def name @name end |
#path ⇒ String
GTM Environment's API relative path.
Corresponds to the JSON property path
1159 1160 1161 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1159 def path @path end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
1164 1165 1166 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1164 def tag_manager_url @tag_manager_url end |
#type ⇒ String
The type of this environment.
Corresponds to the JSON property type
1169 1170 1171 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1169 def type @type end |
#url ⇒ String
Default preview page url for the environment.
Corresponds to the JSON property url
1174 1175 1176 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1174 def url @url end |
#workspace_id ⇒ String
Represents a link to a quick preview of a workspace.
Corresponds to the JSON property workspaceId
1179 1180 1181 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1179 def workspace_id @workspace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1186 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @authorization_code = args[:authorization_code] if args.key?(:authorization_code) @authorization_timestamp = args[:authorization_timestamp] if args.key?(:authorization_timestamp) @container_id = args[:container_id] if args.key?(:container_id) @container_version_id = args[:container_version_id] if args.key?(:container_version_id) @description = args[:description] if args.key?(:description) @enable_debug = args[:enable_debug] if args.key?(:enable_debug) @environment_id = args[:environment_id] if args.key?(:environment_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @type = args[:type] if args.key?(:type) @url = args[:url] if args.key?(:url) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) end |