Class: Google::Apis::TagmanagerV2::Folder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Folder.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Folder

Returns a new instance of Folder.



1255
1256
1257
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1212

def 
  @account_id
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


1217
1218
1219
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1217

def container_id
  @container_id
end

#fingerprintString

The fingerprint of the GTM Folder as computed at storage time. This value is recomputed whenever the folder is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


1223
1224
1225
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1223

def fingerprint
  @fingerprint
end

#folder_idString

The Folder ID uniquely identifies the GTM Folder. Corresponds to the JSON property folderId

Returns:

  • (String)


1228
1229
1230
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1228

def folder_id
  @folder_id
end

#nameString

Folder display name. Corresponds to the JSON property name

Returns:

  • (String)


1233
1234
1235
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1233

def name
  @name
end

#notesString

User notes on how to apply this folder in the container. Corresponds to the JSON property notes

Returns:

  • (String)


1238
1239
1240
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1238

def notes
  @notes
end

#pathString

GTM Folder's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


1243
1244
1245
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1243

def path
  @path
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


1248
1249
1250
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1248

def tag_manager_url
  @tag_manager_url
end

#workspace_idString

GTM Workspace ID. Corresponds to the JSON property workspaceId

Returns:

  • (String)


1253
1254
1255
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1253

def workspace_id
  @workspace_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1260

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @container_id = args[:container_id] if args.key?(:container_id)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @folder_id = args[:folder_id] if args.key?(:folder_id)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @path = args[:path] if args.key?(:path)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @workspace_id = args[:workspace_id] if args.key?(:workspace_id)
end