Class: Google::Apis::TagmanagerV2::GalleryReference
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::GalleryReference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents the link between a custom template and an entry on the Community Template Gallery site.
Instance Attribute Summary collapse
-
#gallery_template_id ⇒ String
ID for the gallery template that is generated once during first sync and travels with the template redirects.
-
#host ⇒ String
The name of the host for the community gallery template.
-
#is_modified ⇒ Boolean
(also: #is_modified?)
If a user has manually edited the community gallery template.
-
#owner ⇒ String
The name of the owner for the community gallery template.
-
#repository ⇒ String
The name of the repository for the community gallery template.
-
#signature ⇒ String
The signature of the community gallery template as computed at import time.
-
#template_developer_id ⇒ String
The developer id of the community gallery template.
-
#version ⇒ String
The version of the community gallery template.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GalleryReference
constructor
A new instance of GalleryReference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GalleryReference
Returns a new instance of GalleryReference.
1390 1391 1392 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gallery_template_id ⇒ String
ID for the gallery template that is generated once during first sync and
travels with the template redirects.
Corresponds to the JSON property galleryTemplateId
1350 1351 1352 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1350 def gallery_template_id @gallery_template_id end |
#host ⇒ String
The name of the host for the community gallery template.
Corresponds to the JSON property host
1355 1356 1357 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1355 def host @host end |
#is_modified ⇒ Boolean Also known as: is_modified?
If a user has manually edited the community gallery template.
Corresponds to the JSON property isModified
1360 1361 1362 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1360 def is_modified @is_modified end |
#owner ⇒ String
The name of the owner for the community gallery template.
Corresponds to the JSON property owner
1366 1367 1368 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1366 def owner @owner end |
#repository ⇒ String
The name of the repository for the community gallery template.
Corresponds to the JSON property repository
1371 1372 1373 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1371 def repository @repository end |
#signature ⇒ String
The signature of the community gallery template as computed at import time.
This value is recomputed whenever the template is updated from the gallery.
Corresponds to the JSON property signature
1377 1378 1379 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1377 def signature @signature end |
#template_developer_id ⇒ String
The developer id of the community gallery template. This value is set whenever
the template is created from the gallery.
Corresponds to the JSON property templateDeveloperId
1383 1384 1385 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1383 def template_developer_id @template_developer_id end |
#version ⇒ String
The version of the community gallery template.
Corresponds to the JSON property version
1388 1389 1390 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1388 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1395 def update!(**args) @gallery_template_id = args[:gallery_template_id] if args.key?(:gallery_template_id) @host = args[:host] if args.key?(:host) @is_modified = args[:is_modified] if args.key?(:is_modified) @owner = args[:owner] if args.key?(:owner) @repository = args[:repository] if args.key?(:repository) @signature = args[:signature] if args.key?(:signature) @template_developer_id = args[:template_developer_id] if args.key?(:template_developer_id) @version = args[:version] if args.key?(:version) end |