Class: Google::Apis::TagmanagerV2::GalleryReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents the link between a custom template and an entry on the Community Template Gallery site.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GalleryReference

Returns a new instance of GalleryReference.



1359
1360
1361
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

ID for the gallery template that is generated once during first sync and travels with the template redirects. Corresponds to the JSON property galleryTemplateId

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1319

def gallery_template_id
  @gallery_template_id
end

#hostString

The name of the host for the community gallery template. Corresponds to the JSON property host

Returns:

  • (String)


1324
1325
1326
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1324

def host
  @host
end

#is_modifiedBoolean Also known as: is_modified?

If a user has manually edited the community gallery template. Corresponds to the JSON property isModified

Returns:

  • (Boolean)


1329
1330
1331
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1329

def is_modified
  @is_modified
end

#ownerString

The name of the owner for the community gallery template. Corresponds to the JSON property owner

Returns:

  • (String)


1335
1336
1337
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1335

def owner
  @owner
end

#repositoryString

The name of the repository for the community gallery template. Corresponds to the JSON property repository

Returns:

  • (String)


1340
1341
1342
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1340

def repository
  @repository
end

#signatureString

The signature of the community gallery template as computed at import time. This value is recomputed whenever the template is updated from the gallery. Corresponds to the JSON property signature

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1346

def signature
  @signature
end

#template_developer_idString

The developer id of the community gallery template. This value is set whenever the template is created from the gallery. Corresponds to the JSON property templateDeveloperId

Returns:

  • (String)


1352
1353
1354
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1352

def template_developer_id
  @template_developer_id
end

#versionString

The version of the community gallery template. Corresponds to the JSON property version

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1357

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1364

def update!(**args)
  @gallery_template_id = args[:gallery_template_id] if args.key?(:gallery_template_id)
  @host = args[:host] if args.key?(:host)
  @is_modified = args[:is_modified] if args.key?(:is_modified)
  @owner = args[:owner] if args.key?(:owner)
  @repository = args[:repository] if args.key?(:repository)
  @signature = args[:signature] if args.key?(:signature)
  @template_developer_id = args[:template_developer_id] if args.key?(:template_developer_id)
  @version = args[:version] if args.key?(:version)
end