Class: Google::Apis::TagmanagerV2::Parameter
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Parameter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Parameter.
Instance Attribute Summary collapse
-
#is_weak_reference ⇒ Boolean
(also: #is_weak_reference?)
Whether or not a reference type parameter is strongly or weakly referenced.
-
#key ⇒ String
The named key that uniquely identifies a parameter.
-
#list ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
This list parameter's parameters (keys will be ignored).
-
#map ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
This map parameter's parameters (must have keys; keys must be unique).
-
#type ⇒ String
The parameter type.
-
#value ⇒ String
A parameter's value (may contain variable references).
Instance Method Summary collapse
-
#initialize(**args) ⇒ Parameter
constructor
A new instance of Parameter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Parameter
Returns a new instance of Parameter.
1992 1993 1994 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#is_weak_reference ⇒ Boolean Also known as: is_weak_reference?
Whether or not a reference type parameter is strongly or weakly referenced.
Only used by Transformations.
Corresponds to the JSON property isWeakReference
1955 1956 1957 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1955 def is_weak_reference @is_weak_reference end |
#key ⇒ String
The named key that uniquely identifies a parameter. Required for top-level
parameters, as well as map values. Ignored for list values.
Corresponds to the JSON property key
1962 1963 1964 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1962 def key @key end |
#list ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
This list parameter's parameters (keys will be ignored).
Corresponds to the JSON property list
1967 1968 1969 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1967 def list @list end |
#map ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
This map parameter's parameters (must have keys; keys must be unique).
Corresponds to the JSON property map
1972 1973 1974 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1972 def map @map end |
#type ⇒ String
The parameter type. Valid values are: - boolean: The value represents a
boolean, represented as 'true' or 'false' - integer: The value represents a 64-
bit signed integer value, in base 10 - list: A list of parameters should be
specified - map: A map of parameters should be specified - template: The value
represents any text; this can include variable references (even variable
references that might return non-string types) - trigger_reference: The value
represents a trigger, represented as the trigger id - tag_reference: The value
represents a tag, represented as the tag name
Corresponds to the JSON property type
1984 1985 1986 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1984 def type @type end |
#value ⇒ String
A parameter's value (may contain variable references). as appropriate to the
specified type.
Corresponds to the JSON property value
1990 1991 1992 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1990 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1997 1998 1999 2000 2001 2002 2003 2004 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 1997 def update!(**args) @is_weak_reference = args[:is_weak_reference] if args.key?(:is_weak_reference) @key = args[:key] if args.key?(:key) @list = args[:list] if args.key?(:list) @map = args[:map] if args.key?(:map) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |