Class: Google::Apis::TagmanagerV2::RevertClientResponse
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::RevertClientResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
The result of reverting a client in a workspace.
Instance Attribute Summary collapse
-
#client ⇒ Google::Apis::TagmanagerV2::Client
Client as it appears in the latest container version since the last workspace synchronization operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RevertClientResponse
constructor
A new instance of RevertClientResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RevertClientResponse
Returns a new instance of RevertClientResponse.
2115 2116 2117 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client ⇒ Google::Apis::TagmanagerV2::Client
Client as it appears in the latest container version since the last workspace
synchronization operation. If no client is present, that means the client was
deleted in the latest container version.
Corresponds to the JSON property client
2113 2114 2115 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2113 def client @client end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2120 2121 2122 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2120 def update!(**args) @client = args[:client] if args.key?(:client) end |