Class: Google::Apis::TagmanagerV2::Tag
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Tag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Tag.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#blocking_trigger_id ⇒ Array<String>
Blocking trigger IDs.
-
#consent_settings ⇒ Google::Apis::TagmanagerV2::TagConsentSetting
Consent settings of a tag.
-
#container_id ⇒ String
GTM Container ID.
-
#fingerprint ⇒ String
The fingerprint of the GTM Tag as computed at storage time.
-
#firing_trigger_id ⇒ Array<String>
Firing trigger IDs.
-
#live_only ⇒ Boolean
(also: #live_only?)
If set to true, this tag will only fire in the live environment (e.g. not in preview or debug mode).
-
#monitoring_metadata ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#monitoring_metadata_tag_name_key ⇒ String
If non-empty, then the tag display name will be included in the monitoring metadata map using the key specified.
-
#name ⇒ String
Tag display name.
-
#notes ⇒ String
User notes on how to apply this tag in the container.
-
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The tag's parameters.
-
#parent_folder_id ⇒ String
Parent folder id.
-
#path ⇒ String
GTM Tag's API relative path.
-
#paused ⇒ Boolean
(also: #paused?)
Indicates whether the tag is paused, which prevents the tag from firing.
-
#priority ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a tag.
-
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a tag.
-
#setup_tag ⇒ Array<Google::Apis::TagmanagerV2::SetupTag>
The list of setup tags.
-
#tag_firing_option ⇒ String
Option to fire this tag.
-
#tag_id ⇒ String
The Tag ID uniquely identifies the GTM Tag.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#teardown_tag ⇒ Array<Google::Apis::TagmanagerV2::TeardownTag>
The list of teardown tags.
-
#type ⇒ String
GTM Tag Type.
-
#workspace_id ⇒ String
GTM Workspace ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tag
constructor
A new instance of Tag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tag
Returns a new instance of Tag.
2519 2520 2521 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
2390 2391 2392 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2390 def account_id @account_id end |
#blocking_trigger_id ⇒ Array<String>
Blocking trigger IDs. If any of the listed triggers evaluate to true, the tag
will not fire.
Corresponds to the JSON property blockingTriggerId
2396 2397 2398 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2396 def blocking_trigger_id @blocking_trigger_id end |
#consent_settings ⇒ Google::Apis::TagmanagerV2::TagConsentSetting
Consent settings of a tag.
Corresponds to the JSON property consentSettings
2401 2402 2403 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2401 def @consent_settings end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
2406 2407 2408 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2406 def container_id @container_id end |
#fingerprint ⇒ String
The fingerprint of the GTM Tag as computed at storage time. This value is
recomputed whenever the tag is modified.
Corresponds to the JSON property fingerprint
2412 2413 2414 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2412 def fingerprint @fingerprint end |
#firing_trigger_id ⇒ Array<String>
Firing trigger IDs. A tag will fire when any of the listed triggers are true
and all of its blockingTriggerIds (if any specified) are false.
Corresponds to the JSON property firingTriggerId
2418 2419 2420 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2418 def firing_trigger_id @firing_trigger_id end |
#live_only ⇒ Boolean Also known as: live_only?
If set to true, this tag will only fire in the live environment (e.g. not in
preview or debug mode).
Corresponds to the JSON property liveOnly
2424 2425 2426 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2424 def live_only @live_only end |
#monitoring_metadata ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property monitoringMetadata
2430 2431 2432 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2430 def @monitoring_metadata end |
#monitoring_metadata_tag_name_key ⇒ String
If non-empty, then the tag display name will be included in the monitoring
metadata map using the key specified.
Corresponds to the JSON property monitoringMetadataTagNameKey
2436 2437 2438 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2436 def @monitoring_metadata_tag_name_key end |
#name ⇒ String
Tag display name.
Corresponds to the JSON property name
2441 2442 2443 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2441 def name @name end |
#notes ⇒ String
User notes on how to apply this tag in the container.
Corresponds to the JSON property notes
2446 2447 2448 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2446 def notes @notes end |
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The tag's parameters.
Corresponds to the JSON property parameter
2451 2452 2453 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2451 def parameter @parameter end |
#parent_folder_id ⇒ String
Parent folder id.
Corresponds to the JSON property parentFolderId
2456 2457 2458 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2456 def parent_folder_id @parent_folder_id end |
#path ⇒ String
GTM Tag's API relative path.
Corresponds to the JSON property path
2461 2462 2463 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2461 def path @path end |
#paused ⇒ Boolean Also known as: paused?
Indicates whether the tag is paused, which prevents the tag from firing.
Corresponds to the JSON property paused
2466 2467 2468 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2466 def paused @paused end |
#priority ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property priority
2472 2473 2474 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2472 def priority @priority end |
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a tag.
Corresponds to the JSON property scheduleEndMs
2477 2478 2479 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2477 def schedule_end_ms @schedule_end_ms end |
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a tag.
Corresponds to the JSON property scheduleStartMs
2482 2483 2484 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2482 def schedule_start_ms @schedule_start_ms end |
#setup_tag ⇒ Array<Google::Apis::TagmanagerV2::SetupTag>
The list of setup tags. Currently we only allow one.
Corresponds to the JSON property setupTag
2487 2488 2489 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2487 def setup_tag @setup_tag end |
#tag_firing_option ⇒ String
Option to fire this tag.
Corresponds to the JSON property tagFiringOption
2492 2493 2494 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2492 def tag_firing_option @tag_firing_option end |
#tag_id ⇒ String
The Tag ID uniquely identifies the GTM Tag.
Corresponds to the JSON property tagId
2497 2498 2499 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2497 def tag_id @tag_id end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
2502 2503 2504 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2502 def tag_manager_url @tag_manager_url end |
#teardown_tag ⇒ Array<Google::Apis::TagmanagerV2::TeardownTag>
The list of teardown tags. Currently we only allow one.
Corresponds to the JSON property teardownTag
2507 2508 2509 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2507 def teardown_tag @teardown_tag end |
#type ⇒ String
GTM Tag Type.
Corresponds to the JSON property type
2512 2513 2514 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2512 def type @type end |
#workspace_id ⇒ String
GTM Workspace ID.
Corresponds to the JSON property workspaceId
2517 2518 2519 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2517 def workspace_id @workspace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2524 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @blocking_trigger_id = args[:blocking_trigger_id] if args.key?(:blocking_trigger_id) @consent_settings = args[:consent_settings] if args.key?(:consent_settings) @container_id = args[:container_id] if args.key?(:container_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @firing_trigger_id = args[:firing_trigger_id] if args.key?(:firing_trigger_id) @live_only = args[:live_only] if args.key?(:live_only) @monitoring_metadata = args[:monitoring_metadata] if args.key?(:monitoring_metadata) @monitoring_metadata_tag_name_key = args[:monitoring_metadata_tag_name_key] if args.key?(:monitoring_metadata_tag_name_key) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @parameter = args[:parameter] if args.key?(:parameter) @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id) @path = args[:path] if args.key?(:path) @paused = args[:paused] if args.key?(:paused) @priority = args[:priority] if args.key?(:priority) @schedule_end_ms = args[:schedule_end_ms] if args.key?(:schedule_end_ms) @schedule_start_ms = args[:schedule_start_ms] if args.key?(:schedule_start_ms) @setup_tag = args[:setup_tag] if args.key?(:setup_tag) @tag_firing_option = args[:tag_firing_option] if args.key?(:tag_firing_option) @tag_id = args[:tag_id] if args.key?(:tag_id) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @teardown_tag = args[:teardown_tag] if args.key?(:teardown_tag) @type = args[:type] if args.key?(:type) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) end |