Class: Google::Apis::TagmanagerV2::Tag
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Tag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Tag.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#blocking_trigger_id ⇒ Array<String>
Blocking trigger IDs.
-
#consent_settings ⇒ Google::Apis::TagmanagerV2::TagConsentSetting
Consent settings of a tag.
-
#container_id ⇒ String
GTM Container ID.
-
#fingerprint ⇒ String
The fingerprint of the GTM Tag as computed at storage time.
-
#firing_trigger_id ⇒ Array<String>
Firing trigger IDs.
-
#live_only ⇒ Boolean
(also: #live_only?)
If set to true, this tag will only fire in the live environment (e.g. not in preview or debug mode).
-
#monitoring_metadata ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#monitoring_metadata_tag_name_key ⇒ String
If non-empty, then the tag display name will be included in the monitoring metadata map using the key specified.
-
#name ⇒ String
Tag display name.
-
#notes ⇒ String
User notes on how to apply this tag in the container.
-
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The tag's parameters.
-
#parent_folder_id ⇒ String
Parent folder id.
-
#path ⇒ String
GTM Tag's API relative path.
-
#paused ⇒ Boolean
(also: #paused?)
Indicates whether the tag is paused, which prevents the tag from firing.
-
#priority ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a tag.
-
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a tag.
-
#setup_tag ⇒ Array<Google::Apis::TagmanagerV2::SetupTag>
The list of setup tags.
-
#tag_firing_option ⇒ String
Option to fire this tag.
-
#tag_id ⇒ String
The Tag ID uniquely identifies the GTM Tag.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#teardown_tag ⇒ Array<Google::Apis::TagmanagerV2::TeardownTag>
The list of teardown tags.
-
#type ⇒ String
GTM Tag Type.
-
#workspace_id ⇒ String
GTM Workspace ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tag
constructor
A new instance of Tag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tag
Returns a new instance of Tag.
2476 2477 2478 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
2347 2348 2349 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2347 def account_id @account_id end |
#blocking_trigger_id ⇒ Array<String>
Blocking trigger IDs. If any of the listed triggers evaluate to true, the tag
will not fire.
Corresponds to the JSON property blockingTriggerId
2353 2354 2355 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2353 def blocking_trigger_id @blocking_trigger_id end |
#consent_settings ⇒ Google::Apis::TagmanagerV2::TagConsentSetting
Consent settings of a tag.
Corresponds to the JSON property consentSettings
2358 2359 2360 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2358 def @consent_settings end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
2363 2364 2365 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2363 def container_id @container_id end |
#fingerprint ⇒ String
The fingerprint of the GTM Tag as computed at storage time. This value is
recomputed whenever the tag is modified.
Corresponds to the JSON property fingerprint
2369 2370 2371 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2369 def fingerprint @fingerprint end |
#firing_trigger_id ⇒ Array<String>
Firing trigger IDs. A tag will fire when any of the listed triggers are true
and all of its blockingTriggerIds (if any specified) are false.
Corresponds to the JSON property firingTriggerId
2375 2376 2377 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2375 def firing_trigger_id @firing_trigger_id end |
#live_only ⇒ Boolean Also known as: live_only?
If set to true, this tag will only fire in the live environment (e.g. not in
preview or debug mode).
Corresponds to the JSON property liveOnly
2381 2382 2383 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2381 def live_only @live_only end |
#monitoring_metadata ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property monitoringMetadata
2387 2388 2389 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2387 def @monitoring_metadata end |
#monitoring_metadata_tag_name_key ⇒ String
If non-empty, then the tag display name will be included in the monitoring
metadata map using the key specified.
Corresponds to the JSON property monitoringMetadataTagNameKey
2393 2394 2395 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2393 def @monitoring_metadata_tag_name_key end |
#name ⇒ String
Tag display name.
Corresponds to the JSON property name
2398 2399 2400 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2398 def name @name end |
#notes ⇒ String
User notes on how to apply this tag in the container.
Corresponds to the JSON property notes
2403 2404 2405 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2403 def notes @notes end |
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The tag's parameters.
Corresponds to the JSON property parameter
2408 2409 2410 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2408 def parameter @parameter end |
#parent_folder_id ⇒ String
Parent folder id.
Corresponds to the JSON property parentFolderId
2413 2414 2415 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2413 def parent_folder_id @parent_folder_id end |
#path ⇒ String
GTM Tag's API relative path.
Corresponds to the JSON property path
2418 2419 2420 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2418 def path @path end |
#paused ⇒ Boolean Also known as: paused?
Indicates whether the tag is paused, which prevents the tag from firing.
Corresponds to the JSON property paused
2423 2424 2425 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2423 def paused @paused end |
#priority ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property priority
2429 2430 2431 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2429 def priority @priority end |
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a tag.
Corresponds to the JSON property scheduleEndMs
2434 2435 2436 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2434 def schedule_end_ms @schedule_end_ms end |
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a tag.
Corresponds to the JSON property scheduleStartMs
2439 2440 2441 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2439 def schedule_start_ms @schedule_start_ms end |
#setup_tag ⇒ Array<Google::Apis::TagmanagerV2::SetupTag>
The list of setup tags. Currently we only allow one.
Corresponds to the JSON property setupTag
2444 2445 2446 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2444 def setup_tag @setup_tag end |
#tag_firing_option ⇒ String
Option to fire this tag.
Corresponds to the JSON property tagFiringOption
2449 2450 2451 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2449 def tag_firing_option @tag_firing_option end |
#tag_id ⇒ String
The Tag ID uniquely identifies the GTM Tag.
Corresponds to the JSON property tagId
2454 2455 2456 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2454 def tag_id @tag_id end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
2459 2460 2461 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2459 def tag_manager_url @tag_manager_url end |
#teardown_tag ⇒ Array<Google::Apis::TagmanagerV2::TeardownTag>
The list of teardown tags. Currently we only allow one.
Corresponds to the JSON property teardownTag
2464 2465 2466 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2464 def teardown_tag @teardown_tag end |
#type ⇒ String
GTM Tag Type.
Corresponds to the JSON property type
2469 2470 2471 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2469 def type @type end |
#workspace_id ⇒ String
GTM Workspace ID.
Corresponds to the JSON property workspaceId
2474 2475 2476 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2474 def workspace_id @workspace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2481 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @blocking_trigger_id = args[:blocking_trigger_id] if args.key?(:blocking_trigger_id) @consent_settings = args[:consent_settings] if args.key?(:consent_settings) @container_id = args[:container_id] if args.key?(:container_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @firing_trigger_id = args[:firing_trigger_id] if args.key?(:firing_trigger_id) @live_only = args[:live_only] if args.key?(:live_only) @monitoring_metadata = args[:monitoring_metadata] if args.key?(:monitoring_metadata) @monitoring_metadata_tag_name_key = args[:monitoring_metadata_tag_name_key] if args.key?(:monitoring_metadata_tag_name_key) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @parameter = args[:parameter] if args.key?(:parameter) @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id) @path = args[:path] if args.key?(:path) @paused = args[:paused] if args.key?(:paused) @priority = args[:priority] if args.key?(:priority) @schedule_end_ms = args[:schedule_end_ms] if args.key?(:schedule_end_ms) @schedule_start_ms = args[:schedule_start_ms] if args.key?(:schedule_start_ms) @setup_tag = args[:setup_tag] if args.key?(:setup_tag) @tag_firing_option = args[:tag_firing_option] if args.key?(:tag_firing_option) @tag_id = args[:tag_id] if args.key?(:tag_id) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @teardown_tag = args[:teardown_tag] if args.key?(:teardown_tag) @type = args[:type] if args.key?(:type) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) end |