Class: Google::Apis::TagmanagerV2::TeardownTag
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::TeardownTag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a tag that fires after another tag in order to tear down dependencies.
Instance Attribute Summary collapse
-
#stop_teardown_on_failure ⇒ Boolean
(also: #stop_teardown_on_failure?)
If true, fire the teardown tag if and only if the main tag fires successfully.
-
#tag_name ⇒ String
The name of the teardown tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeardownTag
constructor
A new instance of TeardownTag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeardownTag
Returns a new instance of TeardownTag.
2553 2554 2555 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stop_teardown_on_failure ⇒ Boolean Also known as: stop_teardown_on_failure?
If true, fire the teardown tag if and only if the main tag fires successfully.
If false, fire the teardown tag regardless of main tag firing status.
Corresponds to the JSON property stopTeardownOnFailure
2545 2546 2547 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2545 def stop_teardown_on_failure @stop_teardown_on_failure end |
#tag_name ⇒ String
The name of the teardown tag.
Corresponds to the JSON property tagName
2551 2552 2553 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2551 def tag_name @tag_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2558 2559 2560 2561 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2558 def update!(**args) @stop_teardown_on_failure = args[:stop_teardown_on_failure] if args.key?(:stop_teardown_on_failure) @tag_name = args[:tag_name] if args.key?(:tag_name) end |