Class: Google::Apis::TagmanagerV2::Trigger
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Trigger
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Trigger
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#auto_event_filter ⇒ Array<Google::Apis::TagmanagerV2::Condition>
Used in the case of auto event tracking.
-
#check_validation ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#container_id ⇒ String
GTM Container ID.
-
#continuous_time_min_milliseconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#custom_event_filter ⇒ Array<Google::Apis::TagmanagerV2::Condition>
Used in the case of custom event, which is fired iff all Conditions are true.
-
#event_name ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#filter ⇒ Array<Google::Apis::TagmanagerV2::Condition>
The trigger will only fire iff all Conditions are true.
-
#fingerprint ⇒ String
The fingerprint of the GTM Trigger as computed at storage time.
-
#horizontal_scroll_percentage_list ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#interval ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#interval_seconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#limit ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#max_timer_length_seconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#name ⇒ String
Trigger display name.
-
#notes ⇒ String
User notes on how to apply this trigger in the container.
-
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
Additional parameters.
-
#parent_folder_id ⇒ String
Parent folder id.
-
#path ⇒ String
GTM Trigger's API relative path.
-
#selector ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#total_time_min_milliseconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#trigger_id ⇒ String
The Trigger ID uniquely identifies the GTM Trigger.
-
#type ⇒ String
Defines the data layer event that causes this trigger.
-
#unique_trigger_id ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#vertical_scroll_percentage_list ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#visibility_selector ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#visible_percentage_max ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#visible_percentage_min ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#wait_for_tags ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#wait_for_tags_timeout ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
-
#workspace_id ⇒ String
GTM Workspace ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Trigger
constructor
A new instance of Trigger.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Trigger
Returns a new instance of Trigger.
2815 2816 2817 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
2657 2658 2659 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2657 def account_id @account_id end |
#auto_event_filter ⇒ Array<Google::Apis::TagmanagerV2::Condition>
Used in the case of auto event tracking.
Corresponds to the JSON property autoEventFilter
2662 2663 2664 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2662 def auto_event_filter @auto_event_filter end |
#check_validation ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property checkValidation
2667 2668 2669 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2667 def check_validation @check_validation end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
2672 2673 2674 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2672 def container_id @container_id end |
#continuous_time_min_milliseconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property continuousTimeMinMilliseconds
2677 2678 2679 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2677 def continuous_time_min_milliseconds @continuous_time_min_milliseconds end |
#custom_event_filter ⇒ Array<Google::Apis::TagmanagerV2::Condition>
Used in the case of custom event, which is fired iff all Conditions are true.
Corresponds to the JSON property customEventFilter
2682 2683 2684 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2682 def custom_event_filter @custom_event_filter end |
#event_name ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property eventName
2687 2688 2689 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2687 def event_name @event_name end |
#filter ⇒ Array<Google::Apis::TagmanagerV2::Condition>
The trigger will only fire iff all Conditions are true.
Corresponds to the JSON property filter
2692 2693 2694 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2692 def filter @filter end |
#fingerprint ⇒ String
The fingerprint of the GTM Trigger as computed at storage time. This value is
recomputed whenever the trigger is modified.
Corresponds to the JSON property fingerprint
2698 2699 2700 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2698 def fingerprint @fingerprint end |
#horizontal_scroll_percentage_list ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property horizontalScrollPercentageList
2703 2704 2705 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2703 def horizontal_scroll_percentage_list @horizontal_scroll_percentage_list end |
#interval ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property interval
2708 2709 2710 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2708 def interval @interval end |
#interval_seconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property intervalSeconds
2713 2714 2715 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2713 def interval_seconds @interval_seconds end |
#limit ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property limit
2718 2719 2720 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2718 def limit @limit end |
#max_timer_length_seconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property maxTimerLengthSeconds
2723 2724 2725 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2723 def max_timer_length_seconds @max_timer_length_seconds end |
#name ⇒ String
Trigger display name.
Corresponds to the JSON property name
2728 2729 2730 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2728 def name @name end |
#notes ⇒ String
User notes on how to apply this trigger in the container.
Corresponds to the JSON property notes
2733 2734 2735 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2733 def notes @notes end |
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
Additional parameters.
Corresponds to the JSON property parameter
2738 2739 2740 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2738 def parameter @parameter end |
#parent_folder_id ⇒ String
Parent folder id.
Corresponds to the JSON property parentFolderId
2743 2744 2745 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2743 def parent_folder_id @parent_folder_id end |
#path ⇒ String
GTM Trigger's API relative path.
Corresponds to the JSON property path
2748 2749 2750 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2748 def path @path end |
#selector ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property selector
2753 2754 2755 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2753 def selector @selector end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
2758 2759 2760 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2758 def tag_manager_url @tag_manager_url end |
#total_time_min_milliseconds ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property totalTimeMinMilliseconds
2763 2764 2765 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2763 def total_time_min_milliseconds @total_time_min_milliseconds end |
#trigger_id ⇒ String
The Trigger ID uniquely identifies the GTM Trigger.
Corresponds to the JSON property triggerId
2768 2769 2770 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2768 def trigger_id @trigger_id end |
#type ⇒ String
Defines the data layer event that causes this trigger.
Corresponds to the JSON property type
2773 2774 2775 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2773 def type @type end |
#unique_trigger_id ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property uniqueTriggerId
2778 2779 2780 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2778 def unique_trigger_id @unique_trigger_id end |
#vertical_scroll_percentage_list ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property verticalScrollPercentageList
2783 2784 2785 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2783 def vertical_scroll_percentage_list @vertical_scroll_percentage_list end |
#visibility_selector ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property visibilitySelector
2788 2789 2790 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2788 def visibility_selector @visibility_selector end |
#visible_percentage_max ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property visiblePercentageMax
2793 2794 2795 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2793 def visible_percentage_max @visible_percentage_max end |
#visible_percentage_min ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property visiblePercentageMin
2798 2799 2800 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2798 def visible_percentage_min @visible_percentage_min end |
#wait_for_tags ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property waitForTags
2803 2804 2805 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2803 def @wait_for_tags end |
#wait_for_tags_timeout ⇒ Google::Apis::TagmanagerV2::Parameter
Represents a Google Tag Manager Parameter.
Corresponds to the JSON property waitForTagsTimeout
2808 2809 2810 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2808 def @wait_for_tags_timeout end |
#workspace_id ⇒ String
GTM Workspace ID.
Corresponds to the JSON property workspaceId
2813 2814 2815 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2813 def workspace_id @workspace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2820 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @auto_event_filter = args[:auto_event_filter] if args.key?(:auto_event_filter) @check_validation = args[:check_validation] if args.key?(:check_validation) @container_id = args[:container_id] if args.key?(:container_id) @continuous_time_min_milliseconds = args[:continuous_time_min_milliseconds] if args.key?(:continuous_time_min_milliseconds) @custom_event_filter = args[:custom_event_filter] if args.key?(:custom_event_filter) @event_name = args[:event_name] if args.key?(:event_name) @filter = args[:filter] if args.key?(:filter) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @horizontal_scroll_percentage_list = args[:horizontal_scroll_percentage_list] if args.key?(:horizontal_scroll_percentage_list) @interval = args[:interval] if args.key?(:interval) @interval_seconds = args[:interval_seconds] if args.key?(:interval_seconds) @limit = args[:limit] if args.key?(:limit) @max_timer_length_seconds = args[:max_timer_length_seconds] if args.key?(:max_timer_length_seconds) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @parameter = args[:parameter] if args.key?(:parameter) @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id) @path = args[:path] if args.key?(:path) @selector = args[:selector] if args.key?(:selector) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @total_time_min_milliseconds = args[:total_time_min_milliseconds] if args.key?(:total_time_min_milliseconds) @trigger_id = args[:trigger_id] if args.key?(:trigger_id) @type = args[:type] if args.key?(:type) @unique_trigger_id = args[:unique_trigger_id] if args.key?(:unique_trigger_id) @vertical_scroll_percentage_list = args[:vertical_scroll_percentage_list] if args.key?(:vertical_scroll_percentage_list) @visibility_selector = args[:visibility_selector] if args.key?(:visibility_selector) @visible_percentage_max = args[:visible_percentage_max] if args.key?(:visible_percentage_max) @visible_percentage_min = args[:visible_percentage_min] if args.key?(:visible_percentage_min) @wait_for_tags = args[:wait_for_tags] if args.key?(:wait_for_tags) @wait_for_tags_timeout = args[:wait_for_tags_timeout] if args.key?(:wait_for_tags_timeout) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) end |