Class: Google::Apis::TagmanagerV2::Variable
- Inherits:
-
Object
- Object
- Google::Apis::TagmanagerV2::Variable
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb
Overview
Represents a Google Tag Manager Variable.
Instance Attribute Summary collapse
-
#account_id ⇒ String
GTM Account ID.
-
#container_id ⇒ String
GTM Container ID.
-
#disabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for disabling conditional variables; the variable is enabled if one of the enabling trigger is true while all the disabling trigger are false.
-
#enabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for enabling conditional variables; the variable is enabled if one of the enabling triggers is true while all the disabling triggers are false.
-
#fingerprint ⇒ String
The fingerprint of the GTM Variable as computed at storage time.
-
#format_value ⇒ Google::Apis::TagmanagerV2::VariableFormatValue
Option to convert a variable value to other value.
-
#name ⇒ String
Variable display name.
-
#notes ⇒ String
User notes on how to apply this variable in the container.
-
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The variable's parameters.
-
#parent_folder_id ⇒ String
Parent folder id.
-
#path ⇒ String
GTM Variable's API relative path.
-
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a variable.
-
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a variable.
-
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI Corresponds to the JSON property
tagManagerUrl. -
#type ⇒ String
GTM Variable Type.
-
#variable_id ⇒ String
The Variable ID uniquely identifies the GTM Variable.
-
#workspace_id ⇒ String
GTM Workspace ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Variable
constructor
A new instance of Variable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Variable
Returns a new instance of Variable.
3036 3037 3038 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3036 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ String
GTM Account ID.
Corresponds to the JSON property accountId
2949 2950 2951 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2949 def account_id @account_id end |
#container_id ⇒ String
GTM Container ID.
Corresponds to the JSON property containerId
2954 2955 2956 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2954 def container_id @container_id end |
#disabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for disabling conditional
variables; the variable is enabled if one of the enabling trigger is true
while all the disabling trigger are false. Treated as an unordered set.
Corresponds to the JSON property disablingTriggerId
2961 2962 2963 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2961 def disabling_trigger_id @disabling_trigger_id end |
#enabling_trigger_id ⇒ Array<String>
For mobile containers only: A list of trigger IDs for enabling conditional
variables; the variable is enabled if one of the enabling triggers is true
while all the disabling triggers are false. Treated as an unordered set.
Corresponds to the JSON property enablingTriggerId
2968 2969 2970 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2968 def enabling_trigger_id @enabling_trigger_id end |
#fingerprint ⇒ String
The fingerprint of the GTM Variable as computed at storage time. This value is
recomputed whenever the variable is modified.
Corresponds to the JSON property fingerprint
2974 2975 2976 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2974 def fingerprint @fingerprint end |
#format_value ⇒ Google::Apis::TagmanagerV2::VariableFormatValue
Option to convert a variable value to other value.
Corresponds to the JSON property formatValue
2979 2980 2981 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2979 def format_value @format_value end |
#name ⇒ String
Variable display name.
Corresponds to the JSON property name
2984 2985 2986 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2984 def name @name end |
#notes ⇒ String
User notes on how to apply this variable in the container.
Corresponds to the JSON property notes
2989 2990 2991 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2989 def notes @notes end |
#parameter ⇒ Array<Google::Apis::TagmanagerV2::Parameter>
The variable's parameters.
Corresponds to the JSON property parameter
2994 2995 2996 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2994 def parameter @parameter end |
#parent_folder_id ⇒ String
Parent folder id.
Corresponds to the JSON property parentFolderId
2999 3000 3001 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 2999 def parent_folder_id @parent_folder_id end |
#path ⇒ String
GTM Variable's API relative path.
Corresponds to the JSON property path
3004 3005 3006 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3004 def path @path end |
#schedule_end_ms ⇒ Fixnum
The end timestamp in milliseconds to schedule a variable.
Corresponds to the JSON property scheduleEndMs
3009 3010 3011 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3009 def schedule_end_ms @schedule_end_ms end |
#schedule_start_ms ⇒ Fixnum
The start timestamp in milliseconds to schedule a variable.
Corresponds to the JSON property scheduleStartMs
3014 3015 3016 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3014 def schedule_start_ms @schedule_start_ms end |
#tag_manager_url ⇒ String
Auto generated link to the tag manager UI
Corresponds to the JSON property tagManagerUrl
3019 3020 3021 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3019 def tag_manager_url @tag_manager_url end |
#type ⇒ String
GTM Variable Type.
Corresponds to the JSON property type
3024 3025 3026 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3024 def type @type end |
#variable_id ⇒ String
The Variable ID uniquely identifies the GTM Variable.
Corresponds to the JSON property variableId
3029 3030 3031 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3029 def variable_id @variable_id end |
#workspace_id ⇒ String
GTM Workspace ID.
Corresponds to the JSON property workspaceId
3034 3035 3036 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3034 def workspace_id @workspace_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 |
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3041 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @container_id = args[:container_id] if args.key?(:container_id) @disabling_trigger_id = args[:disabling_trigger_id] if args.key?(:disabling_trigger_id) @enabling_trigger_id = args[:enabling_trigger_id] if args.key?(:enabling_trigger_id) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @format_value = args[:format_value] if args.key?(:format_value) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @parameter = args[:parameter] if args.key?(:parameter) @parent_folder_id = args[:parent_folder_id] if args.key?(:parent_folder_id) @path = args[:path] if args.key?(:path) @schedule_end_ms = args[:schedule_end_ms] if args.key?(:schedule_end_ms) @schedule_start_ms = args[:schedule_start_ms] if args.key?(:schedule_start_ms) @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url) @type = args[:type] if args.key?(:type) @variable_id = args[:variable_id] if args.key?(:variable_id) @workspace_id = args[:workspace_id] if args.key?(:workspace_id) end |