Class: Google::Apis::TagmanagerV2::Zone

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Zone's contents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Zone

Returns a new instance of Zone.



3246
3247
3248
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


3188
3189
3190
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3188

def 
  @account_id
end

#boundaryGoogle::Apis::TagmanagerV2::ZoneBoundary

Represents a Zone's boundaries. Corresponds to the JSON property boundary



3193
3194
3195
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3193

def boundary
  @boundary
end

#child_containerArray<Google::Apis::TagmanagerV2::ZoneChildContainer>

Containers that are children of this Zone. Corresponds to the JSON property childContainer



3198
3199
3200
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3198

def child_container
  @child_container
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


3203
3204
3205
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3203

def container_id
  @container_id
end

#fingerprintString

The fingerprint of the GTM Zone as computed at storage time. This value is recomputed whenever the zone is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


3209
3210
3211
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3209

def fingerprint
  @fingerprint
end

#nameString

Zone display name. Corresponds to the JSON property name

Returns:

  • (String)


3214
3215
3216
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3214

def name
  @name
end

#notesString

User notes on how to apply this zone in the container. Corresponds to the JSON property notes

Returns:

  • (String)


3219
3220
3221
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3219

def notes
  @notes
end

#pathString

GTM Zone's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


3224
3225
3226
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3224

def path
  @path
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


3229
3230
3231
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3229

def tag_manager_url
  @tag_manager_url
end

#type_restrictionGoogle::Apis::TagmanagerV2::ZoneTypeRestriction

Represents a Zone's type restrictions. Corresponds to the JSON property typeRestriction



3234
3235
3236
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3234

def type_restriction
  @type_restriction
end

#workspace_idString

GTM Workspace ID. Corresponds to the JSON property workspaceId

Returns:

  • (String)


3239
3240
3241
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3239

def workspace_id
  @workspace_id
end

#zone_idString

The Zone ID uniquely identifies the GTM Zone. Corresponds to the JSON property zoneId

Returns:

  • (String)


3244
3245
3246
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3244

def zone_id
  @zone_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3251

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @boundary = args[:boundary] if args.key?(:boundary)
  @child_container = args[:child_container] if args.key?(:child_container)
  @container_id = args[:container_id] if args.key?(:container_id)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @path = args[:path] if args.key?(:path)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @type_restriction = args[:type_restriction] if args.key?(:type_restriction)
  @workspace_id = args[:workspace_id] if args.key?(:workspace_id)
  @zone_id = args[:zone_id] if args.key?(:zone_id)
end