Class: Google::Apis::TagmanagerV2::Zone

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/tagmanager_v2/classes.rb,
lib/google/apis/tagmanager_v2/representations.rb,
lib/google/apis/tagmanager_v2/representations.rb

Overview

Represents a Google Tag Manager Zone's contents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Zone

Returns a new instance of Zone.



3190
3191
3192
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

GTM Account ID. Corresponds to the JSON property accountId

Returns:

  • (String)


3132
3133
3134
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3132

def 
  @account_id
end

#boundaryGoogle::Apis::TagmanagerV2::ZoneBoundary

Represents a Zone's boundaries. Corresponds to the JSON property boundary



3137
3138
3139
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3137

def boundary
  @boundary
end

#child_containerArray<Google::Apis::TagmanagerV2::ZoneChildContainer>

Containers that are children of this Zone. Corresponds to the JSON property childContainer



3142
3143
3144
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3142

def child_container
  @child_container
end

#container_idString

GTM Container ID. Corresponds to the JSON property containerId

Returns:

  • (String)


3147
3148
3149
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3147

def container_id
  @container_id
end

#fingerprintString

The fingerprint of the GTM Zone as computed at storage time. This value is recomputed whenever the zone is modified. Corresponds to the JSON property fingerprint

Returns:

  • (String)


3153
3154
3155
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3153

def fingerprint
  @fingerprint
end

#nameString

Zone display name. Corresponds to the JSON property name

Returns:

  • (String)


3158
3159
3160
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3158

def name
  @name
end

#notesString

User notes on how to apply this zone in the container. Corresponds to the JSON property notes

Returns:

  • (String)


3163
3164
3165
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3163

def notes
  @notes
end

#pathString

GTM Zone's API relative path. Corresponds to the JSON property path

Returns:

  • (String)


3168
3169
3170
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3168

def path
  @path
end

#tag_manager_urlString

Auto generated link to the tag manager UI Corresponds to the JSON property tagManagerUrl

Returns:

  • (String)


3173
3174
3175
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3173

def tag_manager_url
  @tag_manager_url
end

#type_restrictionGoogle::Apis::TagmanagerV2::ZoneTypeRestriction

Represents a Zone's type restrictions. Corresponds to the JSON property typeRestriction



3178
3179
3180
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3178

def type_restriction
  @type_restriction
end

#workspace_idString

GTM Workspace ID. Corresponds to the JSON property workspaceId

Returns:

  • (String)


3183
3184
3185
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3183

def workspace_id
  @workspace_id
end

#zone_idString

The Zone ID uniquely identifies the GTM Zone. Corresponds to the JSON property zoneId

Returns:

  • (String)


3188
3189
3190
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3188

def zone_id
  @zone_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
3205
3206
3207
3208
# File 'lib/google/apis/tagmanager_v2/classes.rb', line 3195

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @boundary = args[:boundary] if args.key?(:boundary)
  @child_container = args[:child_container] if args.key?(:child_container)
  @container_id = args[:container_id] if args.key?(:container_id)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @path = args[:path] if args.key?(:path)
  @tag_manager_url = args[:tag_manager_url] if args.key?(:tag_manager_url)
  @type_restriction = args[:type_restriction] if args.key?(:type_restriction)
  @workspace_id = args[:workspace_id] if args.key?(:workspace_id)
  @zone_id = args[:zone_id] if args.key?(:zone_id)
end